pub struct IgnoreTracker { /* private fields */ }Expand description
Tracks ignored rules per line
Implementations
Sourceimpl IgnoreTracker
impl IgnoreTracker
Sourcepub fn is_ignored(&self, rule: &str, line: usize) -> bool
pub fn is_ignored(&self, rule: &str, line: usize) -> bool
Check if a rule is ignored on a specific line
Sourcepub fn from_content(content: &str) -> (Self, Vec<IgnoreWarning>)
pub fn from_content(content: &str) -> (Self, Vec<IgnoreWarning>)
Build an ignore tracker from content, returning any warnings
Sourcepub fn from_content_with_rules(
content: &str,
valid_rules: Option<&HashSet<String>>,
) -> (Self, Vec<IgnoreWarning>)
pub fn from_content_with_rules( content: &str, valid_rules: Option<&HashSet<String>>, ) -> (Self, Vec<IgnoreWarning>)
Build an ignore tracker from content with optional rule name validation
Sourcepub fn unused_warnings(&self) -> Vec<IgnoreWarning>
pub fn unused_warnings(&self) -> Vec<IgnoreWarning>
Get warnings for unused ignore directives