pub enum Severity {
Error,
Warning,
}Expand description
Severity level of a lint diagnostic.
Variants
Error— the configuration is broken or has a critical security issue.Warning— the configuration works but uses discouraged settings or could be improved.
Variants
Error
The configuration will not work correctly, or there is a critical security issue.
Warning
A discouraged setting, potential problem, or improvement suggestion.