pub struct FixApplyResult {
pub content: String,
pub applied: usize,
pub skipped_invalid: usize,
}Expand description
Result of applying fixes to content, with detailed counts.
Fields
content: StringContent after applying the fixes
applied: usizeNumber of fixes applied
skipped_invalid: usizeNumber of fixes skipped because they could not be applied: offsets out
of range or not on UTF-8 character boundaries, or a line-based fix
referencing a missing line or old_text (e.g. produced by a buggy
plugin). Does not include fixes skipped due to overlap with an applied
fix.