pub enum NginxVersionParseError {
InvalidFormat(String),
InvalidComponent(String),
}Expand description
Error returned by NginxVersion::parse.
Variants
InvalidFormat(String)
The string did not have the expected three dot-separated components.
InvalidComponent(String)
One of the three components was not a valid u32.